use rust_embed::RustEmbed;

#[derive(RustEmbed)]
#[folder = "template/parts/"]
pub struct Parts;

#[derive(RustEmbed)]
#[folder = "template/pages/"]
pub struct Pages;

#[derive(RustEmbed)]
#[folder = "out"]
pub struct Compiled;

#[derive(RustEmbed)]
#[folder = "template/scripts/external"]
pub struct ExternalScripts;
